"use strict";
/**
 * Serverless - Reload
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Reload = void 0;
const config_js_1 = require("../../config/config.js");
const contentfulData_js_1 = require("../../utils/contentful/contentfulData.js");
const object_js_1 = require("../../utils/object/object.js");
const string_js_1 = require("../../utils/string/string.js");
const function_js_1 = require("../../utils/function/function.js");
const filter_js_1 = require("../../utils/filter/filter.js");
const action_js_1 = require("../../utils/action/action.js");
const shortcode_js_1 = require("../../utils/shortcode/shortcode.js");
const path_js_1 = require("../../utils/path/path.js");
const print_js_1 = require("../../utils/print/print.js");
const render_js_1 = require("../../render/render.js");
/**
 * Output paginated and/or filtered page on browser reload
 *
 * @param {ReloadArgs} args
 * @return {Promise<Response>} Response
 */
const Reload = async ({ request, functionPath, next, env, siteConfig }) => {
    try {
        /* Query */
        const { searchParams, pathname } = new URL(request.url);
        const page = searchParams.get('page');
        const filters = searchParams.get('filters');
        const path = pathname;
        const query = {};
        let noPage = false;
        let noFilters = false;
        if ((0, string_js_1.isStringStrict)(page)) {
            query.page = page;
        }
        else {
            noPage = true;
        }
        if ((0, string_js_1.isStringStrict)(filters)) {
            query.filters = filters;
        }
        else {
            noFilters = true;
        }
        /* No query move on to default page */
        if (noPage || noFilters) {
            return next();
        }
        /* Config */
        (0, config_js_1.setConfig)(siteConfig);
        await (0, config_js_1.setConfigFilter)(env);
        siteConfig.env.dir = (0, path_js_1.getPathDepth)(functionPath);
        (0, filter_js_1.setFilters)(siteConfig.filters);
        (0, action_js_1.setActions)(siteConfig.actions);
        (0, shortcode_js_1.setShortcodes)(siteConfig.shortcodes);
        /* Data params */
        const serverlessData = { query, path };
        /* Output */
        const data = await (0, render_js_1.render)({
            serverlessData,
            allData: await (0, contentfulData_js_1.getAllContentfulData)({
                serverlessData
            })
        });
        let html = '';
        if ((0, object_js_1.isObjectStrict)(data)) {
            html = data.output !== undefined ? data.output : '';
        }
        return new Response(html, {
            status: 200,
            headers: {
                'Content-Type': 'text/html;charset=UTF-8'
            }
        });
    }
    catch (error) {
        (0, print_js_1.print)('[SSF] Error with reload function', error);
        const statusCode = 500;
        let html = '';
        if ((0, function_js_1.isFunction)(config_js_1.config.renderHttpError)) {
            html = await config_js_1.config.renderHttpError({ code: statusCode });
        }
        return new Response(html, {
            status: statusCode,
            headers: {
                'Content-Type': 'text/html;charset=UTF-8'
            }
        });
    }
};
exports.Reload = Reload;
