/**
 * Utils - Archive
 */
import type { ArchiveInfo, ArchiveLinkReturn } from './archiveTypes.js';
import type { Taxonomy } from '../../global/globalTypes.js';
import type { RenderItem } from '../../render/renderTypes.js';
/**
 * Get archive id, slug and title
 *
 * @param {string} contentType
 * @return {ArchiveInfo}
 */
declare const getArchiveInfo: (contentType?: string) => ArchiveInfo;
/**
 * Get taxonomy attributes
 *
 * @param {string} contentType
 * @param {RenderItem} pageData
 * @return {Taxonomy}
 */
declare const getTaxonomyInfo: (contentType: string, pageData: RenderItem | undefined) => Required<Taxonomy>;
/**
 * Get archive link by content type or taxonomy
 *
 * @param {string} contentType
 * @param {RenderItem} [pageData]
 * @return {ArchiveLinkReturn}
 */
declare const getArchiveLink: (contentType?: string, pageData?: RenderItem) => ArchiveLinkReturn;
export { getArchiveInfo, getTaxonomyInfo, getArchiveLink };
