/**
 * Utils - Path
 */
import { config } from '../../config/config.js';
import { isStringStrict } from '../string/string.js';
/**
 * Get absolute path to file or file from config
 *
 * @param {string} file
 * @param {string} [type]
 * @return {string}
 */
const getPath = (file = '', type = '') => {
    const root = config.env.dir;
    if (!isStringStrict(root) || !isStringStrict(file)) {
        return '';
    }
    let append = file;
    if (type === 'store') {
        const dir = config.storeDir;
        const name = config.storeFiles[file]?.name;
        if (isStringStrict(dir) && isStringStrict(name)) {
            append = `${dir}/${name}`;
        }
    }
    if (file === 'image') {
        if (type === 'data') {
            const dataFile = config.image.dataFile;
            if (isStringStrict(dataFile)) {
                append = dataFile;
            }
        }
        if (type === 'input' || type === 'output') {
            const dirName = type === 'input' ? 'inputDir' : 'outputDir';
            const dir = config.image[dirName];
            if (isStringStrict(dir)) {
                append = `${dir}/${file}`;
            }
        }
    }
    if (type === 'serverless') {
        const dir = config.serverlessDir;
        const name = config.serverlessFiles[file];
        if (isStringStrict(dir) && isStringStrict(name)) {
            append = `${dir}/${name}`;
        }
    }
    return `${root}${root.endsWith('/') ? '' : '/'}${append}`;
};
/**
 * Relative ascendent path as string
 *
 * @param {string} path
 * @return {string}
 */
const getPathDepth = (path = '') => {
    let pathDepth = path.split('/');
    pathDepth.pop();
    pathDepth = pathDepth.map(() => {
        return '../';
    });
    return pathDepth.join('');
};
/* Exports */
export { getPath, getPathDepth };
